@@ -33,7 +33,14 @@ from .aenetworks import (
     HistoryTopicIE,
 )
 from .afreecatv import AfreecaTVIE
+from .agora import (
+    TokFMAuditionIE,
+    TokFMPodcastIE,
+    WyborczaPodcastIE,
+    WyborczaVideoIE,
+)
 from .airmozilla import AirMozillaIE
+from .albicla import AlbiclaIE
 from .aljazeera import AlJazeeraIE
 from .alphaporno import AlphaPornoIE
 from .amcnetworks import AMCNetworksIE
@@ -323,6 +330,7 @@ from .engadget import EngadgetIE
 from .eporner import EpornerIE
 from .eroprofile import EroProfileIE
 from .escapist import EscapistIE
+from .eskago import EskaGoIE
 from .espn import (
     ESPNIE,
     ESPNArticleIE,
@@ -330,6 +338,12 @@ from .espn import (
 )
 from .esri import EsriVideoIE
 from .europa import EuropaIE
+from .eurozet import (
+    EurozetArticleIE,
+    EurozetPlayerStreamIE,
+    EurozetPlayerPodcastIE,
+    EurozetPlayerMusicStreamIE,
+)
 from .everyonesmixtape import EveryonesMixtapeIE
 from .expotv import ExpoTVIE
 from .expressen import ExpressenIE
@@ -396,6 +410,14 @@ from .frontendmasters import (
 )
 from .funimation import FunimationIE
 from .funk import FunkIE
+from .funkwhale import (
+    FunkwhaleAlbumSHIE,
+    FunkwhaleArtistSHIE,
+    FunkwhaleChannelSHIE,
+    FunkwhalePlaylistSHIE,
+    FunkwhaleTrackSHIE,
+    FunkwhaleRadioSHIE,
+)
 from .fusion import FusionIE
 from .fxnetworks import FXNetworksIE
 from .gaia import GaiaIE
@@ -423,6 +445,11 @@ from .googlesearch import GoogleSearchIE
 from .goshgay import GoshgayIE
 from .gputechconf import GPUTechConfIE
 from .groupon import GrouponIE
+from .gtv import GtvIE
+from .guardian import (
+    GuardianAudioIE,
+    GuardianVideoIE,
+)
 from .hbo import HBOIE
 from .hearthisat import HearThisAtIE
 from .heise import HeiseIE
@@ -479,6 +506,7 @@ from .instagram import (
 )
 from .internazionale import InternazionaleIE
 from .internetvideoarchive import InternetVideoArchiveIE
+from .ipla import IplaIE
 from .iprima import IPrimaIE
 from .iqiyi import IqiyiIE
 from .ir90tv import Ir90TvIE
@@ -532,6 +560,7 @@ from .laola1tv import (
     EHFTVIE,
     ITTFIE,
 )
+from .lbry import LBRYIE
 from .lci import LCIIE
 from .lcp import (
     LcpPlayIE,
@@ -564,6 +593,7 @@ from .limelight import (
 )
 from .line import LineTVIE
 from .linkedin import (
+    LinkedInPostIE,
     LinkedInLearningIE,
     LinkedInLearningCourseIE,
 )
@@ -583,6 +613,7 @@ from .lnkgo import LnkGoIE
 from .localnews8 import LocalNews8IE
 from .lovehomeporn import LoveHomePornIE
 from .lrt import LRTIE
+from .lurker import LurkerIE
 from .lynda import (
     LyndaIE,
     LyndaCourseIE
@@ -603,6 +634,7 @@ from .markiza import (
     MarkizaIE,
     MarkizaPageIE,
 )
+from .mastodon import MastodonSHIE
 from .massengeschmacktv import MassengeschmackTVIE
 from .matchtv import MatchTVIE
 from .mdr import MDRIE
@@ -732,6 +764,7 @@ from .nick import (
     NickRuIE,
 )
 from .niconico import NiconicoIE, NiconicoPlaylistIE
+from .ninateka import NinatekaIE
 from .ninecninemedia import NineCNineMediaIE
 from .ninegag import NineGagIE
 from .ninenow import NineNowIE
@@ -788,14 +821,10 @@ from .nuvid import NuvidIE
 from .nzz import NZZIE
 from .odatv import OdaTVIE
 from .odnoklassniki import OdnoklassnikiIE
+from .okopress import OKOPressIE
 from .oktoberfesttv import OktoberfestTVIE
 from .ondemandkorea import OnDemandKoreaIE
-from .onet import (
-    OnetIE,
-    OnetChannelIE,
-    OnetMVPIE,
-    OnetPlIE,
-)
+from .onet import OnetPlIE
 from .onionstudios import OnionStudiosIE
 from .onnetwork import (
     OnNetworkLoaderIE,
@@ -805,6 +834,7 @@ from .ooyala import (
     OoyalaIE,
     OoyalaExternalIE,
 )
+from .openfm import OpenFMIE
 from .ora import OraTVIE
 from .orf import (
     ORFTVthekIE,
@@ -833,7 +863,7 @@ from .parliamentliveuk import ParliamentLiveUKIE
 from .patreon import PatreonIE
 from .pbs import PBSIE
 from .pearvideo import PearVideoIE
-from .peertube import PeerTubeIE
+from .peertube import PeerTubeSHIE
 from .people import PeopleIE
 from .performgroup import PerformGroupIE
 from .periscope import (
@@ -869,6 +899,7 @@ from .pokemon import PokemonIE
 from .polskieradio import (
     PolskieRadioIE,
     PolskieRadioCategoryIE,
+    PolskieRadioPlayerIE,
 )
 from .popcorntimes import PopcorntimesIE
 from .popcorntv import PopcornTVIE
@@ -888,6 +919,10 @@ from .puhutv import (
     PuhuTVIE,
     PuhuTVSerieIE,
 )
+from .pulsembed import (
+    PulsEmbedIE,
+    PulseVideoIE,
+)
 from .presstv import PressTVIE
 from .prosiebensat1 import ProSiebenSat1IE
 from .puls4 import Puls4IE
@@ -944,6 +979,11 @@ from .reuters import ReutersIE
 from .reverbnation import ReverbNationIE
 from .rice import RICEIE
 from .rmcdecouverte import RMCDecouverteIE
+from .rmf import (
+    RMFonPodcastsIE,
+    RMFonStreamIE,
+    RMF24IE,
+)
 from .ro220 import Ro220IE
 from .rockstargames import RockstarGamesIE
 from .roosterteeth import RoosterTeethIE
@@ -1176,6 +1216,10 @@ from .traileraddict import TrailerAddictIE
 from .trilulilu import TriluliluIE
 from .trunews import TruNewsIE
 from .trutv import TruTVIE
+from .tubafm import (
+    TubaFMIE,
+    TubaFMPageIE,
+)
 from .tube8 import Tube8IE
 from .tubitv import TubiTvIE
 from .tumblr import TumblrIE
@@ -1212,6 +1256,10 @@ from .tvc import (
 from .tvigle import TvigleIE
 from .tvland import TVLandIE
 from .tvn24 import TVN24IE
+from .tvnplayer import (
+    TVNPlayerIE,
+    TVNPlayerSeriesIE,
+)
 from .tvnet import TVNetIE
 from .tvnoe import TVNoeIE
 from .tvnow import (
@@ -1224,6 +1272,7 @@ from .tvnow import (
 from .tvp import (
     TVPEmbedIE,
     TVPIE,
+    TVPStreamIE,
     TVPWebsiteIE,
 )
 from .tvplay import (
@@ -1418,6 +1467,7 @@ from .weibo import (
 from .weiqitv import WeiqiTVIE
 from .wistia import WistiaIE
 from .worldstarhiphop import WorldStarHipHopIE
+from .wppl import WpPlIE
 from .wsj import (
     WSJIE,
     WSJArticleIE,
@@ -1443,6 +1493,7 @@ from .ximalaya import (
     XimalayaAlbumIE
 )
 from .xminus import XMinusIE
+from .xnews import XLinkIE
 from .xnxx import XNXXIE
 from .xstream import XstreamIE
 from .xtube import XTubeUserIE, XTubeIE
@@ -1483,21 +1534,16 @@ from .yourupload import YourUploadIE
 from .youtube import (
     YoutubeIE,
     YoutubeChannelIE,
-    YoutubeFavouritesIE,
     YoutubeHistoryIE,
-    YoutubeLiveIE,
+    YoutubeLikedIE,
+    YoutubeMusicAlbumIE,
     YoutubePlaylistIE,
-    YoutubePlaylistsIE,
-    YoutubeRecommendedIE,
-    YoutubeSearchDateIE,
     YoutubeSearchIE,
-    YoutubeSearchURLIE,
-    YoutubeShowIE,
     YoutubeSubscriptionsIE,
+    YoutubeWatchLaterIE,
+    YoutubeTopicChannelWorkaroundIE,
     YoutubeTruncatedIDIE,
     YoutubeTruncatedURLIE,
-    YoutubeUserIE,
-    YoutubeWatchLaterIE,
 )
 from .zapiks import ZapiksIE
 from .zaq1 import Zaq1IE
