@@ -675,6 +675,10 @@ def parseOpts(overrideArguments=None):
         '--no-call-home',
         dest='call_home', action='store_false', default=False,
         help='Do NOT contact the haruhi-dl server for debugging')
+    verbosity.add_option(
+        '--no-headless-playwright',
+        dest='headless_playwright', action='store_false', default=False,
+        help='Show browsers automated with Playwright on the screen')
 
     filesystem = optparse.OptionGroup(parser, 'Filesystem Options')
     filesystem.add_option(
